import { Config, ConfigOptions, Plugin } from 'cli-engine-config';
import { HTTP } from 'http-call';
import { args } from 'cli-flags';
import { IFlag } from './flags';
export declare type MockReturn<T extends Command> = {
    cmd: T;
    stdout: string;
    stderr: string;
};
export declare type CommandRunFn = <T extends Command>(this: CommandClass<T>, config?: ConfigOptions) => Promise<T>;
export declare type CommandMockFn = <T extends Command>(this: CommandClass<T>, ...argv: string[]) => Promise<MockReturn<T>>;
export interface CommandClass<T extends Command> {
    new ({config}: {
        config?: ConfigOptions;
    }): T;
    run: CommandRunFn;
    mock: CommandMockFn;
}
export declare class Command {
    static topic: string;
    static command: string | undefined;
    static description: string | undefined;
    static hidden: boolean;
    static usage: string | undefined;
    static help: string | undefined;
    static aliases: string[];
    static variableArgs: boolean;
    static flags: {
        [name: string]: IFlag<any>;
    };
    static args: args.IArg[];
    static _version: any;
    static plugin: Plugin | undefined;
    static readonly id: string;
    /**
     * instantiate and run the command setting {mock: true} in the config (shorthand method)
     */
    static mock: CommandMockFn;
    /**
     * instantiate and run the command
     */
    static run: CommandRunFn;
    readonly ctor: typeof Command;
    config: Config;
    http: typeof HTTP;
    flags: {
        [name: string]: any;
    };
    argv: string[];
    args: {
        [name: string]: string;
    };
    constructor(options?: {
        config?: ConfigOptions;
    });
    init(): Promise<void>;
    topic: null;
    command: null;
    description: null;
    hidden: null;
    usage: null;
    help: null;
    aliases: null;
    /**
     * actual command run code goes here
     */
    run(): Promise<void>;
    static buildHelp(config: Config): string;
    static buildHelpLine(config: Config): [string, string | undefined];
}
