"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pjson = require('../package.json');
const deps_1 = require("./deps");
class Command {
    constructor(options = {}) {
        this.flags = {};
        this.args = {};
        this.config = deps_1.default.Config.buildConfig(options.config);
        this.argv = this.config.argv;
        this.http = deps_1.default.HTTP.defaults({
            headers: {
                'user-agent': `${this.config.name}/${this.config.version} (${this.config.platform}-${this.config.arch}) node-${process.version}`,
            },
        });
    }
    static get id() {
        let cmd = [];
        if (this.topic)
            cmd.push(this.topic);
        if (this.command)
            cmd.push(this.command);
        return cmd.join(':');
    }
    get ctor() {
        return this.constructor;
    }
    async init() {
        const { argv, flags, args } = await deps_1.default.CLIFlags.parse({
            flags: this.ctor.flags || {},
            argv: this.argv.slice(1),
            args: this.ctor.args || [],
            strict: !this.ctor.variableArgs,
        });
        this.flags = flags;
        this.argv = argv;
        this.args = args;
    }
    /**
     * actual command run code goes here
     */
    async run() { }
    static buildHelp(config) {
        let help = new deps_1.default.Help(config);
        return help.command(this);
    }
    static buildHelpLine(config) {
        let help = new deps_1.default.Help(config);
        return help.commandLine(this);
    }
}
Command.aliases = [];
Command.variableArgs = false;
Command.args = [];
Command._version = pjson.version;
/**
 * instantiate and run the command setting {mock: true} in the config (shorthand method)
 */
Command.mock = async function (...argv) {
    argv.unshift('cmd');
    const cmd = await this.run({ argv, mock: true });
    return {
        cmd,
        stdout: deps_1.default.cli.stdout.output,
        stderr: deps_1.default.cli.stderr.output,
    };
};
/**
 * instantiate and run the command
 */
Command.run = async function (config) {
    const cmd = new this({ config });
    try {
        await cmd.init();
        await cmd.run();
        await deps_1.default.cli.done();
    }
    catch (err) {
        deps_1.default.cli.error(err);
    }
    return cmd;
};
exports.Command = Command;
