"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const help_1 = require("./help");
const command_1 = require("./command");
const cli_engine_config_1 = require("cli-engine-config");
const cli_flags_1 = require("cli-flags");
class Command extends command_1.Command {
    async run() {
        return;
    }
}
class AppsCreate extends Command {
}
AppsCreate.topic = 'apps';
AppsCreate.command = 'create';
AppsCreate.description = 'description of apps:create';
AppsCreate.help = `some

multiline help
`;
AppsCreate.args = [{ name: 'app_name', description: 'app to use' }];
AppsCreate.flags = {
    force: cli_flags_1.flags.boolean({ description: 'force it' }),
    app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
    foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
    remote: cli_flags_1.flags.string({ char: 'r' }),
};
const help = new help_1.Help(cli_engine_config_1.buildConfig({
    aliases: {
        'apps:create2': ['foo', 'bar'],
    },
}));
describe('commandLine()', () => {
    test('has help', () => {
        expect(help.command(AppsCreate)).toEqual(`Usage: cli-engine apps:create [APP_NAME] [flags]

description of apps:create

APP_NAME  app to use

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it

some

multiline help
`);
    });
    class AppsCreate3 extends Command {
    }
    AppsCreate3.topic = 'apps';
    AppsCreate3.command = 'create';
    AppsCreate3.flags = {
        force: cli_flags_1.flags.boolean({ description: 'force it' }),
        app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
        foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
        remote: cli_flags_1.flags.string({ char: 'r' }),
    };
    test('has just flags', () => {
        expect(help.command(AppsCreate3)).toEqual(`Usage: cli-engine apps:create [flags]

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it
`);
    });
    test('has flags + description', () => {
        class CMD extends Command {
        }
        CMD.topic = 'apps';
        CMD.command = 'create';
        CMD.description = 'description of apps:create';
        CMD.flags = {
            force: cli_flags_1.flags.boolean({ description: 'force it' }),
            app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
            foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
            remote: cli_flags_1.flags.string({ char: 'r' }),
        };
        expect(help.command(CMD)).toEqual(`Usage: cli-engine apps:create [flags]

description of apps:create

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it
`);
    });
    class AppsCreate1 extends Command {
    }
    AppsCreate1.topic = 'apps';
    AppsCreate1.command = 'create';
    AppsCreate1.help = 'description of apps:create';
    AppsCreate1.flags = {
        force: cli_flags_1.flags.boolean({ description: 'force it' }),
        app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
        foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
        remote: cli_flags_1.flags.string({ char: 'r' }),
    };
    test('has description + help', () => {
        expect(help.command(AppsCreate1)).toEqual(`Usage: cli-engine apps:create [flags]

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it

description of apps:create
`);
    });
    class AppsCreate2 extends Command {
    }
    AppsCreate2.topic = 'apps';
    AppsCreate2.command = 'create';
    AppsCreate2.description = 'description of apps:create';
    AppsCreate2.args = [{ name: 'app_name', description: 'app to use' }];
    test('has description + args', () => {
        expect(help.command(AppsCreate2)).toEqual(`Usage: cli-engine apps:create [APP_NAME]

description of apps:create

APP_NAME  app to use
`);
    });
    class CMD extends Command {
    }
    CMD.topic = 'apps';
    CMD.command = 'create2';
    CMD.description = 'description of apps:create2';
    CMD.args = [{ name: 'app_name', description: 'app to use' }];
    test('has aliases', () => {
        expect(help.command(CMD)).toEqual(`Usage: cli-engine apps:create2 [APP_NAME]

description of apps:create2

Aliases:
  $ cli-engine foo
  $ cli-engine bar

APP_NAME  app to use
`);
    });
});
describe('command()', () => {
    test('has command help', () => {
        expect(help.commandLine(AppsCreate)).toEqual(['apps:create [APP_NAME]', 'description of apps:create']);
    });
});
